summaryrefslogtreecommitdiffstats
path: root/src/OSSupport/File.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/OSSupport/File.h')
-rw-r--r--src/OSSupport/File.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/OSSupport/File.h b/src/OSSupport/File.h
index 6ee080480..dc6543180 100644
--- a/src/OSSupport/File.h
+++ b/src/OSSupport/File.h
@@ -124,9 +124,14 @@ public:
/** Creates a new folder with the specified name. Returns true if successful. Path may be relative or absolute */
static bool CreateFolder(const AString & a_FolderPath);
- /** Returns the entire contents of the specified file as a string. Returns empty string on error. */
+ // tolua_end
+
+ /** Returns the entire contents of the specified file as a string. Returns empty string on error.
+ Exported manually in ManualBindings.cpp due to #1914 - ToLua code doesn't work well with binary files. */
static AString ReadWholeFile(const AString & a_FileName);
+ // tolua_begin
+
/** Returns a_FileName with its extension changed to a_NewExt.
a_FileName may contain path specification. */
static AString ChangeFileExt(const AString & a_FileName, const AString & a_NewExt);